@@ -27,8 +27,12 @@ from ._datasets import (
     spleen_lymph_cite_seq,
     synthetic_iid,
 )
-from ._preprocessing import organize_cite_seq_10x, poisson_gene_selection
-from ._read import read_10x_atac
+from ._preprocessing import (
+    organize_cite_seq_10x,
+    organize_multiome_anndatas,
+    poisson_gene_selection,
+)
+from ._read import read_10x_atac, read_10x_multiome
 
 __all__ = [
     "setup_anndata",
@@ -60,5 +64,7 @@ __all__ = [
     "read_loom",
     "read_text",
     "read_10x_atac",
+    "read_10x_multiome",
     "heart_cell_atlas_subsampled",
+    "organize_multiome_anndatas",
 ]
