@@ -2,6 +2,7 @@ from ._autozi import AUTOZI
 from ._condscvi import CondSCVI
 from ._destvi import DestVI
 from ._linear_scvi import LinearSCVI
+from ._multivi import MULTIVI
 from ._peakvi import PEAKVI
 from ._scanvi import SCANVI
 from ._scvi import SCVI
@@ -16,4 +17,5 @@ __all__ = [
     "PEAKVI",
     "CondSCVI",
     "DestVI",
+    "MULTIVI",
 ]
