@@ -1,6 +1,7 @@
 from ._autozivae import AutoZIVAE
 from ._classifier import Classifier
 from ._mrdeconv import MRDeconv
+from ._multivae import MULTIVAE
 from ._peakvae import PEAKVAE
 from ._scanvae import SCANVAE
 from ._totalvae import TOTALVAE
@@ -17,4 +18,5 @@ __all__ = [
     "PEAKVAE",
     "VAEC",
     "MRDeconv",
+    "MULTIVAE",
 ]
